@@ -24,6 +24,7 @@
 #include "dialog.h"
 #include "slot.h"
 #include "statistics.h"
+#include "menu.h"
 
 /* These have been lifted straight from eog. */
 
@@ -92,17 +93,19 @@ static gboolean cards_are_droppable (hslot_type hslot) {
                                                   scm_long2num (hslot->id)));
 }
 
-static void find_drop_target(gint x, gint y, hslot_type* hslot, gint* cardid) {
+static hslot_type find_drop_target(gint x, gint y) {
   hslot_type new_hslot;
+  hslot_type retval = NULL;
   gint i, new_cardid;
   gint min_distance = G_MAXINT;
 
   /* Find a target directly under the center of the card. */
   slot_pressed(x + card_width / 2,
                y + card_height / 2,
-               hslot, cardid);
-  if (*hslot)
-    return;
+	       &new_hslot, &new_cardid);
+
+  if (new_hslot && cards_are_droppable (new_hslot))
+    return new_hslot;
 
   /* If that didn't work, look for a target at all 4 corners of the card. */
   for (i = 0; i < 4; i++) {
@@ -113,23 +116,24 @@ static void find_drop_target(gint x, gint y, hslot_type* hslot, gint* cardid) {
     if (!new_hslot)
 	continue;
 	
-        /* This skips corners we know are not droppable. */
+    /* This skips corners we know are not droppable. */
     if (!droppable_is_featured
         || cards_are_droppable (new_hslot)) {
       gint dx, dy, distance_squared;
 
-      dx = abs(new_hslot->pixelx + new_cardid*new_hslot->pixeldx - x);
-      dy = abs(new_hslot->pixely + new_cardid*new_hslot->pixeldy - y);
+      dx = new_hslot->pixelx + new_cardid*new_hslot->pixeldx - x;
+      dy = new_hslot->pixely + new_cardid*new_hslot->pixeldy - y;
 
       distance_squared = dx*dx + dy*dy;
 
       if (distance_squared <= min_distance) {
-        *hslot = new_hslot;
-        *cardid = new_cardid;
+	retval = new_hslot;
         min_distance = distance_squared;
       }
     }
   }
+
+  return retval;
 }
 
 static void set_cursor (int cursor)
@@ -174,6 +178,7 @@ void end_of_game_test() {
       refresh_screen ();
       if (game_won) { /* Check because we can undo lost games. */
 	game_in_progress = FALSE;
+	option_list_set_sensitive ();
 	update_statistics (TRUE, timer_get ());
       }
       show_game_over_dialog ();
@@ -185,11 +190,10 @@ void drop_moving_cards(gint x, gint y) {
   GList* temp;
   SCM cardlist = SCM_EOL;
   hslot_type hslot;
-  gint cardid, moved = 0;
+  gint moved = 0;
   gint width, height;
 
-  find_drop_target(x - press_data->xoffset, y - press_data->yoffset,
-                   &hslot, &cardid);
+  hslot = find_drop_target(x - press_data->xoffset, y - press_data->yoffset);
 
   if (hslot) {
     for (temp = press_data->cards; temp; temp = temp->next)
@@ -258,8 +262,8 @@ static void highlight_drop_target(hslot_type hslot) {
       } 
     }
 
-  /* This ensures that the moving cards are on top.*/
-  gdk_window_show (press_data->moving_cards);
+    /* This ensures that the moving cards are on top.*/
+    gdk_window_show (press_data->moving_cards); 
   }
 }
 
@@ -274,6 +278,7 @@ gint button_press_event (GtkWidget *widget, GdkEventButton *event, void *d)
 
   if (!game_in_progress) {
     game_in_progress = TRUE;
+    option_list_set_sensitive ();
     timer_start ();
   }
 
@@ -436,21 +441,29 @@ gint button_release_event (GtkWidget *widget, GdkEventButton *event, void *d)
 
 gint motion_notify_event (GtkWidget *widget, GdkEventMotion *event)
 {
-  if (press_data->status == STATUS_IS_DRAG) {
-    hslot_type (hslot);
-    gint cardid;
+  gint x, y;
 
-    find_drop_target(event->x - press_data->xoffset,
-                     event->y - press_data->yoffset,
-                     &hslot, &cardid); 
+  if (press_data->status == STATUS_IS_DRAG) {
+    hslot_type hslot;
+
+    hslot = find_drop_target(event->x - press_data->xoffset,
+			     event->y - press_data->yoffset);
     
     highlight_drop_target(hslot);
 
-    gdk_window_move(press_data->moving_cards,  
-		    event->x - press_data->xoffset,
-		    event->y - press_data->yoffset);
+    x = event->x - press_data->xoffset;
+    y = event->y - press_data->yoffset;
 
-    gdk_window_clear(press_data->moving_cards);
+    gdk_window_move(press_data->moving_cards, x, y);
+
+    /* This is a quick and nasty hack to make sure that the areas
+     * under the transparent corners of the dragged card get drawn
+     * properly. */
+    gdk_draw_drawable (playing_area->window, playing_area->style->black_gc,
+		       surface, x, y, x, y, 
+		       press_data->width, press_data->height);
+
+    gdk_window_clear(press_data->moving_cards); 
     set_cursor (CURSOR_CLOSED);
   }
   else if (press_data->status == STATUS_MAYBE_DRAG &&
@@ -535,3 +548,17 @@ gint configure_event (GtkWidget *widget, GdkEventConfigure *event) {
   return FALSE;
 }
 
+gint expose_event (GtkWidget *widget, GdkEventExpose *event) 
+{
+
+  if (!surface)
+    return TRUE;
+
+  gdk_draw_drawable (widget->window, widget->style->black_gc,
+		     surface, event->area.x, event->area.y,
+		     event->area.x, event->area.y,
+		     event->area.width, event->area.height);
+
+  return FALSE;
+}
+
