@@ -125,7 +125,7 @@ network_game_dialog_show (GtkWidget *parent_window)
   
   game_dialog = gtk_dialog_new_with_buttons (_("New Network Game"),
                     			     GTK_WINDOW(parent_window),
-				             0, NULL);
+				             0, NULL, NULL);
   gtk_dialog_set_has_separator (GTK_DIALOG (game_dialog), FALSE);
   gtk_container_set_border_width (GTK_CONTAINER (game_dialog), 5);
   gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (game_dialog)->vbox), 2);
@@ -164,7 +164,7 @@ network_game_dialog_show (GtkWidget *parent_window)
     
   server = gconf_client_get_string (conf_client, KEY_NETWORK_SERVER, NULL);
   if (server == NULL) {
-    gtk_entry_set_text (GTK_ENTRY(server_entry), game_server);
+    gtk_entry_set_text (GTK_ENTRY(server_entry), games_network_server_name);
   } else {
     gtk_entry_set_text (GTK_ENTRY(server_entry), server);
   }
@@ -355,7 +355,7 @@ connect_cb (GtkWidget *widget)
   gconf_client_set_int (conf_client, KEY_NETWORK_MODE, network_mode, NULL);
 
   if (server == NULL) {
-    server = game_server;
+    server = games_network_server_name;
   }
 
   if (network_mode == SERVER_MODE) {
